@@ -7,7 +7,7 @@ use strict;
 
 use parent 'Exporter';
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 our @ISA = 'Exporter';
 our @EXPORT_OK = qw();
 
@@ -31,7 +31,7 @@ any useful code, so check sub-modules, please.
 
 XML::TMX::Writer, XML::TMX::Reader, XML::TMX::FromPO
 
-L<XML::Writer(3)>, TMX Specification L<http://www.lisa.org/tmx/tmx.htm>
+L<XML::Writer(3)>, TMX Specification L<https://www.gala-global.org/oscarStandards/tmx/tmx14b.html>
 
 =head1 AUTHOR
 
