@@ -453,7 +453,7 @@ deprecated. use C<for_tu>
 
 =head1 SEE ALSO
 
-L<XML::Writer(3)>, TMX Specification L<http://www.lisa.org/tmx/tmx.htm>
+L<XML::Writer(3)>, TMX Specification L<https://www.gala-global.org/oscarStandards/tmx/tmx14b.html>
 
 =head1 AUTHOR
 
