@@ -464,7 +464,7 @@ sub end_tmx {
 
 =head1 SEE ALSO
 
-TMX Specification L<http://www.lisa.org/tmx/tmx.htm>
+TMX Specification L<https://www.gala-global.org/oscarStandards/tmx/tmx14b.html>
 
 =head1 AUTHOR
 
